@@ -6,20 +6,22 @@ no strict 'refs'; # we're fiddling with the symbol table
 
 use Class::Inspector;
 
-=encoding utf8
-
 =head1 NAME
 
 Class::Unload - Unload a class
 
 =head1 VERSION
 
-Version 0.03
+Version 0.05
 
 =cut
 
-our $VERSION = '0.03';
+use 5.005;
+use vars qw($VERSION);
 
+BEGIN {
+	$VERSION = '0.05';
+}
 
 =head1 SYNOPSIS
 
@@ -67,7 +69,7 @@ sub unload {
 
 =head1 AUTHOR
 
-Dagfinn Ilmari Mannsåker, C<< <ilmari at ilmari.org> >>
+Dagfinn Ilmari Mannsker, C<< <ilmari at ilmari.org> >>
 
 =head1 SEE ALSO
 
@@ -126,7 +128,7 @@ and pointers.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 Dagfinn Ilmari Mannsåker.
+Copyright 2008 Dagfinn Ilmari Mannsker.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
